#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#   (C) Copyright 2009, APT-Portal Developers
#    https://launchpad.net/~apt-portal-devs
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

# This is the main server launcher
#
import cherrypy
from optparse import OptionParser
import sys
import os
from cherrypy.lib import cptools
from cherrypy_mako import *

def load_package(package_dir):
    # Load all the controllers here
    if not package_dir in sys.path:
        sys.path.insert(0, package_dir)
    modules = [fname[:-3] for fname in os.listdir(package_dir) if fname.endswith(".py")]
    imported_modules = [__import__(fname) for fname in modules]
    sys.path.remove(package_dir)
    return imported_modules

class Root(object):
    @cherrypy.expose
    def index(self):        
        cptools.redirect('./welcome')

if __name__ == '__main__':
    parser = OptionParser()
    (options, args) = parser.parse_args()
    if len(args) < 1:
        print "Usage %s application" % __file__
        sys.exit(2)

    application = args[0]
            
    current_dir = os.path.dirname(os.path.abspath(__file__))
    # Set up site-wide config first so we get a log if errors occur.
    cherrypy.config.update({'environment': 'production',
                            'log.error_file': 'site.log',
                            'log.screen': True})
    # Enable gzip compression
    cherrypy.config.update({'tools.gzip.on': 'True'})
                            
    # Setup the static content directories
    conf = {'/': {'tools.staticdir.root': os.path.join(current_dir \
                , "applications", application, 'static')}, \
            '/media': {'tools.staticdir.on': True, \
                     'tools.staticdir.dir': os.path.join(current_dir \
                , "applications", application, 'static','media')},
            '/css': {'tools.staticdir.on': True, \
                     'tools.staticdir.dir': os.path.join(current_dir \
                , "applications", application, 'static','css')},
            '/js': {'tools.staticdir.on': True, \
                    'tools.staticdir.dir': os.path.join(current_dir \
                , "applications", application, 'static', 'js')}}
                
    set_templates_directory(os.path.join(current_dir, "applications" \
        ,application,"views"))
        
    cherrypy.root = Root()
    cherrypy.root.pt_PT = cherrypy.root

    # Load the controllers    
    load_package("controllers/")
    
    # Start the server
    cherrypy.quickstart(cherrypy.root, '/', config=conf)
